@@ -50,7 +50,7 @@ def eval_cost(x, step_param_names, step_objfunc, calib_params, req_queue, files,
 
 def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters: int, options: Dict,
                 n_threads: int = 4, rtol: float = 0.001, ftol: float = -np.inf,
-                full_trace: List = None, rounds_below: int = 1, async: bool = True) -> Tuple:
+                full_trace: List = None, rounds_below: int = 1, conf: Dict = {}) -> Tuple:
     """Performs a stepwise particle swarm optimization PSO using a global best approach.
 
         Parameters
@@ -127,7 +127,9 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
     thread_pool = []
     for thread_no in range(n_threads):
         worker = Thread(target=csip_worker, args=(req_queue, thread_no, lambda: done,
-                                                  full_trace, args['url'], args['files'], args['param'], async))
+                                                  full_trace, args['url'], args['files'], args['param'],
+                                                  conf)
+                        )
         thread_pool.append(worker)
         worker.start()
 
